Module: DSLKit::BlankSlate

Defined in:
lib/dslkit/polite.rb

Class Method Summary collapse

Class Method Details

.with(*ids) ⇒ Object

Creates an anonymous blank slate class, that only responds to the methods *ids. ids can be Symbols, Strings, and Regexps that have to match the method name with #===.



381
382
383
384
385
386
387
388
389
390
391
392
# File 'lib/dslkit/polite.rb', line 381

def self.with(*ids)
  opts = Hash === ids.last ? ids.pop : {}
  ids = ids.map { |id| Regexp === id ? id : id.to_s }
  klass = opts[:superclass] ? Class.new(opts[:superclass]) : Class.new
  klass.instance_eval do
    instance_methods.each do |m|
      m = m.to_s
      undef_method m unless m =~ /^(__|object_id)/ or ids.any? { |i| i === m }
    end
  end
  klass
end