Module: DSLKit::ConstantMaker

Defined in:
lib/dslkit/polite.rb

Overview

This module can be used to extend another module/class. It generates symbols for every missing constant under the namespace of this module/class.

Instance Method Summary collapse

Instance Method Details

#const_missing(id) ⇒ Object

Returns a symbol (id) for every missing constant named id.



372
373
374
# File 'lib/dslkit/polite.rb', line 372

def const_missing(id)
  id
end