Module: DSLKit::MethodMissingDelegator::DelegatorModule
- Includes:
- DSLKit::MethodMissingDelegator
- Included in:
- DelegatorClass
- Defined in:
- lib/dslkit/polite.rb
Overview
Including this module in your classes makes an initialize method available, whose first argument is used as method_missing_delegator attribute. If a superior initialize method was defined it is called with all arguments but the first.
Instance Attribute Summary
Attributes included from DSLKit::MethodMissingDelegator
Instance Method Summary collapse
Methods included from DSLKit::MethodMissingDelegator
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class DSLKit::MethodMissingDelegator
Instance Method Details
#initialize(delegator, *a, &b) ⇒ Object
580 581 582 583 |
# File 'lib/dslkit/polite.rb', line 580 def initialize(delegator, *a, &b) self.method_missing_delegator = delegator super(*a, &b) if defined? super end |