Module: DSLKit::ParameterizedModule
- Included in:
- FromModule, Module
- Defined in:
- lib/dslkit/polite.rb
Instance Method Summary collapse
-
#parameterize_for(*args, &block) ⇒ Object
Pass args and block to configure the module and then return it after calling the parameterize method has been called with these arguments.
Instance Method Details
#parameterize_for(*args, &block) ⇒ Object
Pass args and block to configure the module and then return it after calling the parameterize method has been called with these arguments. The parameterize method should return a configured module.
611 612 613 |
# File 'lib/dslkit/polite.rb', line 611 def parameterize_for(*args, &block) respond_to?(:parameterize) ? parameterize(*args, &block) : self end |